# Test Inka

---
1. Test Entry from inka development:
> For manual tests
> data directory: '/Users/Q187392/Library/Application Support/Anki2'
> ```bash
> sqlite3 prefs21.db .dump > prefs21_dump.sql
> ```
> inside $\sqrt{2}$ text
> This is inline math: $E=mc^2$ and block math:
> $$
> E = mc^2
> $$
> 
> $$
> \operatorname{ker} f=\{g\in G:f(g)=e_{H}\}{\mbox{.}}
> $$

---
